contacts.Person (Person) — amici1

# `contacts.Person` (Person)

Person(id, email, language, url, phone, gsm, fax, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, prefix, name, remarks, partner_ptr, title, first_name, middle_name, last_name, gender, birth_date)

Master tables : contacts.Persons (Persons)

Slave tables : cal.EntriesByGuest (Calendar entries), cal.GuestsByPartner (Presences), contacts.RolesByPerson (Contact for), courses.ActivitiesByTeacher (Activities), courses.EnrolmentsByPupil (Enrolments in Activities), courses.EntriesByTeacher (Calendar entries), households.MembersByPerson (Household memberships), households.SiblingsByPerson (Household composition), humanlinks.LinksByHuman (Human Links)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- e-mail address (email) : The primary email address.

- Language (language) : The language to use when communicating with this partner.

- URL (url) : See `<django.db.models.fields.URLField: url>`.

- Phone (phone) : The primary phone number.

- GSM (gsm) : The primary mobile phone number.

- Fax (fax) : See `<django.db.models.fields.CharField: fax>`.

- Country (country) : See `<django.db.models.fields.related.ForeignKey: country>`.

- Locality (city) : The locality, i.e. usually a village, city or town.

- Zip code (zip_code) : See `<django.db.models.fields.CharField: zip_code>`.

- County (region) : See `<django.db.models.fields.related.ForeignKey: region>`.

- Address line before street (addr1) : Address line before street

- Street prefix (street_prefix) : Text to print before name of street, but to ignore for sorting.

- Street (street) : Name of street, without house number.

- No. (street_no) : House number.

- Box (street_box) : Text to print after street number on the same line.

- Address line after street (addr2) : Address line to print below street line.

- Name prefix (prefix) : An optional name prefix. For organisations this is inserted before the name, for persons this is inserted between first name and last name.

- Name (name) : The full name of this partner. Used for alphabetic sorting.

- Remarks (remarks) : See `<django.db.models.fields.TextField: remarks>`.

- Payment term (payment_term) : The default payment term for sales invoices to this customer.

- Purchase account (purchase_account) : The general account to suggest as default value in purchase invoices from this partner.

- Partner (partner_ptr) : See `<django.db.models.fields.related.OneToOneField: partner_ptr>`.

- Title (title) : Used to specify a professional position or academic qualification like “Dr.” or “PhD”.

- First name (first_name) : The first name, also known as given name.

- Middle name (middle_name) : A space-separated list of all middle names.

- Last name (last_name) : The last name, also known as family name.

- Gender (gender) : The sex of this person (male or female).

- Birth date (birth_date) : Uncomplete dates are allowed, e.g. “00.00.1980” means “some day in 1980”, “00.07.1980” means “in July 1980” or “23.07.0000” means “on a 23th of July”.

- Name (name_column) : See `lino_amici.lib.contacts.models.Person.name_column`.

- (None) (navigation_panel) : See `lino_amici.lib.contacts.models.Person.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_amici.lib.contacts.models.Person.overview`.

- Age (age) : Virtual field displaying the age in years.

- Contact details (contact_details) : See `lino_amici.lib.contacts.models.Person.contact_details`.

- See as (mti_navigator) : A virtual field which defines buttons for switching between the different views.

- Address (address_column) : See `lino_amici.lib.contacts.models.Person.address_column`.

- Municipality (municipality) : The municipality, i.e. either the city or a parent of it.

- (None) (overview) : See `lino_amici.lib.contacts.models.Person.overview`.

Referenced from cal.Guest.partner, cal.Room.contact_person, contacts.Role.person, courses.Course.teacher, courses.Enrolment.pupil, courses.Line.contact_person, excerpts.Excerpt.contact_person, households.Member.person, humanlinks.Link.child, humanlinks.Link.parent

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
email | e-mail address | The primary email address.
language | Language | The language to use when communicating with this partner.
url | URL |
phone | Phone | The primary phone number.
gsm | GSM | The primary mobile phone number.
fax | Fax |
country | Country |
city | Locality | The locality, i.e. usually a village, city or town.
zip_code | Zip code |
region | County |
addr1 | Address line before street | Address line before street
street_prefix | Street prefix | Text to print before name of street, but to ignore for sorting.
street | Street | Name of street, without house number.
street_no | No. | House number.
street_box | Box | Text to print after street number on the same line.
addr2 | Address line after street | Address line to print below street line.
prefix | Name prefix | An optional name prefix. For organisations this is inserted before the name, for persons this is inserted between first name and last name.
name | Name | The full name of this partner. Used for alphabetic sorting.
remarks | Remarks |
payment_term | Payment term | The default payment term for sales invoices to this customer.
purchase_account | Purchase account | The general account to suggest as default value in purchase invoices from this partner.
partner_ptr | Partner |
title | Title | Used to specify a professional position or academic qualification like “Dr.” or “PhD”.
first_name | First name | The first name, also known as given name.
middle_name | Middle name | A space-separated list of all middle names.
last_name | Last name | The last name, also known as family name.
gender | Gender | The sex of this person (male or female).
birth_date | Birth date | Uncomplete dates are allowed, e.g. “00.00.1980” means “some day in 1980”, “00.07.1980” means “in July 1980” or “23.07.0000” means “on a 23th of July”.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
age | Age | Virtual field displaying the age in years.
contact_details | Contact details |
mti_navigator | See as | A virtual field which defines buttons for switching between the different views.
address_column | Address |
municipality | Municipality | The municipality, i.e. either the city or a parent of it.
overview | None |